@@ -16,5 +16,5 @@ def colorprint(text,color_name):
 def codecprint(text,color_name):
     color_print.Color.output_color.color_print(text,color_name)
 
-def setcolor_name(color_name):
+def setcolor(color_name):
     color_print.Color.output_color.setcolor(color_name)
\ No newline at end of file
