@@ -160,17 +160,17 @@ class Color():
 
             
             """
-            #get now color
+            
+            
             info_ = cutil.console_screen_buffer_info()
             cutil.GetConsoleInfo(cutil.stdout_handle, byref(info_))
-
-            #change console color
-            cutil.SetConsoleAttribute(cutil.stdout_handle,color | info_.wAttributes & 0x0070)
-
-            #default print
+            
+            fg_color = color | 0x0008
+            cutil.SetConsoleAttribute(cutil.stdout_handle,
+                                       fg_color | info_.wAttributes & 0x0070)
+            
             print(text)
-
-            #reset color
+            
             cutil.SetConsoleAttribute(cutil.stdout_handle, info_.wAttributes)
 
             return text
@@ -183,10 +183,10 @@ class Color():
             #change console color
             cutil.SetConsoleAttribute(cutil.stdout_handle,color | info_.wAttributes & 0x0070)
 
-        def setcolor_name(color_name):
+        def setcolor(color):
             color_list=Color.Color_list.Color()
 
-            color = (((color_list[color_name])))
+            color = (((color_list[color])))
 
             color = color.format(len(color)-1)
 
